@@ -27,12 +27,14 @@ def add_images_to_existing_project(session, projnumber):
                 project_team.append(user)
 
     if existing_project is None:
-        click.secho(f"🤯 {projnumber} does not exist ANYWHERE, please create it manually on ams.ftrack.com and run the script again", fg="yellow")
+        click.secho(
+            f"🤯 {projnumber} does not exist ANYWHERE, please create it manually on ams.ftrack.com and run the script again", fg="yellow")
     else:
         print(f'🥳 Found {existing_project["name"]} in {existing_team["name"]}')
 
         if "Archive" in existing_project['parent']["name"]:
-            print(f'So {existing_project["name"]} was found but it was archived, so we moved it to Projects')
+            print(
+                f'So {existing_project["name"]} was found but it was archived, so we moved it to Projects')
 
             for ps in existing_team["children"]:
                 if ps["name"] == "Projects":
@@ -52,7 +54,8 @@ def add_images_to_existing_project(session, projnumber):
             num_exist_int = len(int_folder["children"])
             print(f'{existing_project["name"]} already has {num_exist_int} INT images')
         else:
-            print(f"{existing_project['name']} has no INT images, let's create a folder for them!")
+            print(
+                f"{existing_project['name']} has no INT images, let's create a folder for them!")
             int_folder = session.create(
                 "Folder",
                 {
@@ -65,9 +68,11 @@ def add_images_to_existing_project(session, projnumber):
         if exterior_shots is not None and len(exterior_shots) > 0:
             ext_folder = exterior_shots[0]
             num_existing_ext = len(ext_folder["children"])
-            print(f'{existing_project["name"]} already has {num_existing_ext} EXT images')
+            print(
+                f'{existing_project["name"]} already has {num_existing_ext} EXT images')
         else:
-            print(f"{existing_project['name']} has no EXT images, let's create a folder for them!")
+            print(
+                f"{existing_project['name']} has no EXT images, let's create a folder for them!")
             ext_folder = session.create(
                 "Folder",
                 {
@@ -93,7 +98,8 @@ def add_images_to_existing_project(session, projnumber):
 
         while True:
             try:
-                additional_exteriors = int(input("Enter amount of additional EXT shots: "))
+                additional_exteriors = int(
+                    input("Enter amount of additional EXT shots: "))
             except ValueError:
                 print("Sorry, I didn't understand that? Did you type a number?")
                 continue
@@ -130,7 +136,7 @@ def add_images_to_existing_project(session, projnumber):
         for i in range(num_existing_ext, num_existing_ext + additional_exteriors):
             shot = shotnumber_to_letter(i)
             print(f"📸 EXT {shot} for {ext_artist['username']}")
-            ext_shot_name = f"{projnumber}_INT_{shot}"
+            ext_shot_name = f"{projnumber}_EXT_{shot}"
 
             ext_shot = session.create("Image", {
                                       "name": ext_shot_name,
