@@ -34,6 +34,7 @@ def create_new_project(session):
     clearConsole()
     num = None
     dealnumber = None
+    deal = None
     if get_yes_no("Do you have a deal number?"):
         while True:
             dealnumber = input("Enter deal number: ")
@@ -325,7 +326,7 @@ def create_new_project(session):
                     "Appointment",
                     {
                         "context": task,
-                        "resource": project_manager,
+                        "resource": artist,
                         "type": "assignment",
                     },
                 )
